@@ -455,7 +455,7 @@ end
        | Dot (s,l,r) -> Dot (s, aux l, aux r)
        | Var i -> 
 	   begin match find t i  with
-	     | None -> Errors.error "aac_tactics: instantiate failure"
+	     | None -> CErrors.error "aac_tactics: instantiate failure"
 	     | Some x -> t_of_term  x
 	   end
      in aux x
@@ -1092,7 +1092,7 @@ let unit_warning p ~nullif ~unitif =
   if not (Search.is_empty unitif)
   then
     begin
-      Pp.msg_warning
+      Feedback.msg_warning
 	(Pp.str
 	   "[aac_tactics] This pattern can be instanciated to match units, some solutions can be missing");
     end
