@@ -10,7 +10,7 @@
     tactic. *)
 
 
-(** The main printing function. {!print} uses the [Term.rel_context]
+(** The main printing function. {!print} uses the rel-context
     to rename the variables, and rebuilds raw Coq terms (for the given
     context, and the terms in the environment). In order to do so, it
     requires the information gathered by the {!Theory.Trans} module.*)
@@ -18,6 +18,6 @@ val print :
   Coq.Relation.t ->
   Theory.Trans.ir ->
   (int * Matcher.Terms.t * Matcher.Subst.t Search_monad.m) Search_monad.m ->
-  Context.rel_context  ->
+  Context.Rel.t  ->
   Proof_type.tactic
 
